==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnSelectionEventArgsDetailDescriptionMetadata } from "./WebColumnSelectionEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDescription } from "./WebColumnSelectionEventArgsDescription";
/**
 * @hidden
 */
var WebColumnSelectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnSelectionEventArgsDescriptionMetadata, _super);
    function WebColumnSelectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnSelectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnSelectionEventArgsDescriptionMetadata.a == null) {
            WebColumnSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnSelectionEventArgsDescriptionMetadata.c(WebColumnSelectionEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnSelectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnSelectionEventArgsDescriptionMetadata.a);
        WebColumnSelectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnSelectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebColumnSelectionEventArgsDetail");
    };
    WebColumnSelectionEventArgsDescriptionMetadata.d = function (a) {
        WebColumnSelectionEventArgsDescriptionMetadata.b(a);
        a.aa("WebColumnSelectionEventArgs", function () { return new WebColumnSelectionEventArgsDescription(); });
        a.z("WebColumnSelectionEventArgs", WebColumnSelectionEventArgsDescriptionMetadata.a);
    };
    WebColumnSelectionEventArgsDescriptionMetadata.$t = markType(WebColumnSelectionEventArgsDescriptionMetadata, 'WebColumnSelectionEventArgsDescriptionMetadata');
    WebColumnSelectionEventArgsDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDescriptionMetadata;
}(Base));
export { WebColumnSelectionEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnSelectionEventArgsDetailDescriptionMetadata } from "./WebColumnSelectionEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDescription } from "./WebColumnSelectionEventArgsDescription";
/**
 * @hidden
 */
var WebColumnSelectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnSelectionEventArgsDescriptionMetadata, _super);
    function WebColumnSelectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnSelectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnSelectionEventArgsDescriptionMetadata.a == null) {
            WebColumnSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnSelectionEventArgsDescriptionMetadata.c(WebColumnSelectionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnSelectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnSelectionEventArgsDescriptionMetadata.a);
        WebColumnSelectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnSelectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnSelectionEventArgsDetail");
    };
    WebColumnSelectionEventArgsDescriptionMetadata.d = function (a) {
        WebColumnSelectionEventArgsDescriptionMetadata.b(a);
        a.ac("WebColumnSelectionEventArgs", function () { return new WebColumnSelectionEventArgsDescription(); });
        a.ab("WebColumnSelectionEventArgs", WebColumnSelectionEventArgsDescriptionMetadata.a);
    };
    WebColumnSelectionEventArgsDescriptionMetadata.$t = markType(WebColumnSelectionEventArgsDescriptionMetadata, 'WebColumnSelectionEventArgsDescriptionMetadata');
    WebColumnSelectionEventArgsDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDescriptionMetadata;
}(Base));
export { WebColumnSelectionEventArgsDescriptionMetadata };
